#ifndef CG_RENDERAREA_H
#define CG_RENDERAREA_H

#include <vector>
#include <iostream>

#include <QtOpenGL/QGLWidget>
#include <QtGui/QImage>

#include "mesh.h"

using namespace std;

class GLWidget : public QGLWidget 
{
    Q_OBJECT

public:            
    enum TexMode { SPHERE = 0, CYLINDER = 1 };    

    GLWidget(QWidget *parent = 0, QGLFormat format = QGLFormat());
	~GLWidget();
    
public slots:        
    bool loadModel(const QString &filename);
	bool loadTexture(const QString &filename);
    void setTexMode(int mode);
	
protected:
	// functions
	void initializeGL();
	void resizeGL(int w, int h);
	void paintGL();

	void mouseMoveEvent(QMouseEvent *e);
	void mousePressEvent(QMouseEvent *e);

	Vector3D pick(int x, int y);         
	void generateTextureCoordinates();
	void bindTexture();

	// variables
	Mesh*			m_mesh;
	TexMode			m_texMode;
    
    QImage			m_qImageTexture;
    unsigned int	m_textureId;
       
 
	QPoint			m_lastPos;

	float			m_xTrans;
	float			m_yTrans;
	float			m_zTrans;
    float			m_rotationMatrix[16];

	GLfloat			m_fovy;
	GLfloat			m_zNear;
	GLfloat			m_zFar;
};

#endif
